@@ -16,7 +16,7 @@ let sure f =
     | None ->
 	None
 
-let maybe f x = try Some (f x) with _ -> None
+let maybe f x = try Some (f x) with Not_found -> None
 let tee f x = try ignore @@ f x; x with _ -> x
 
 type ('a,'b) either = Val of 'a | Err of 'b
@@ -51,6 +51,17 @@ let map_accum_left f init xs =
     List.fold_left f (init,[]) xs in
     accum,List.rev ys
 
+let rec map_accum_right f init =
+  function
+      [] ->
+	init,[]
+    | x::xs ->
+	let (accum,ys) =
+	  map_accum_right f init xs in
+	let (accum,y) =
+	  f accum x in
+	  accum,y::ys
+
 let rec group_by f =
   function
       [] ->
@@ -85,4 +96,21 @@ let hex =
 let todo x =
   failwith x
 
+let open_out_with path f =
+  let ch =
+    open_out_bin path in
+  let s =
+    f ch in
+    close_out ch;
+    s
 
+let open_in_with path f =
+  let ch =
+    open_in_bin path in
+  let s =
+    f ch in
+    close_in ch;
+    s
+
+let undefined =
+  Obj.magic 42
