@@ -5,4 +5,4 @@
 (define (inc x)
   (+ x 1))
 
-(print (inc x))
\ No newline at end of file
+(trace (inc x))
\ No newline at end of file
