@@ -2,4 +2,4 @@
 ;;
 ;; expect output:
 ;;; Hello,world!!
-(print "Hello,world!!")
\ No newline at end of file
+(trace "Hello,world!!")
\ No newline at end of file
