@@ -4,5 +4,5 @@
 
 (let ((x 42))
   (let ((x 10))
-    (print "inner scope:" x))
-  (print "outer scope:" x))
+    (trace "inner scope:" x))
+  (trace "outer scope:" x))
